==> om-7.x-1.0.tar.gz: om/core/template.php <==
<?php
// $Id: template.php,v 1.1.4.1 2011/02/09 12:14:04 danielhonrade Exp $

/**
 * Logo, Site Name, Site Slogan
 */
function om_identity($logo, $site_name, $site_slogan, $front_page) {
  if (!empty($logo)) { 
	  $out = '<div id="logo-title">';
    if (!empty($logo)) { 
      $out .= '<a href="' . $front_page . '" title="' . t('Home') . '" rel="home" id="logo">';
      $out .= '<img src="' . $logo . '" alt="' . t('Home') . '" />';
      $out .= '</a>';
	  }
		if (!empty($logo) || !empty($site_name) || !empty($site_slogan)) { 
        $out .= '<div id="name-and-slogan">';
        if (!empty($site_name)) {
          $out .= '<h1 id="site-name">';
          $out .= '<a href="' . $front_page . '" title=' . t('Home') . '" rel="home">' . $site_name . '</a>';
          $out .= '</h1>';
				}
        if (!empty($site_slogan)) {
          $out .= '<div id="site-slogan">' . $site_slogan . '</div>';
        }
        $out .= '</div> <!-- /name-and-slogan -->';
     }    
     $out .= '</div> <!-- /logo-title -->';
	}
	return $out;
}


/**
 * Primary, Secondary Menus
 *
function om_menu($menu_name = NULL, $menu = NULL, $menu_tree = NULL) {
	if(!empty($menu)) { 
			$output = '<div id="menubar-' . $menu_name. '" class="menubar">' . $menu_tree . '</div>';
  }
  return $output;
}

/**
 * Process all region formats
 */
function om_region_wrapper($region_name = NULL, $region = NULL, $region_inner = 0) {
  if ($region) { 
    if($region_inner == 1) { 
      $div_prefix = '<div id="' . $region_name . '" class="region"><div id="' . $region_name . '-inner" class="region-inner">'; 
      $div_suffix = '<div class="clearfix"></div></div><!-- ' . $region_name . '-inner --></div><!-- ' . $region_name . ' -->'; 
    }
    else {
      $div_prefix = '<div id="' . $region_name . '" class="region">'; 
      $div_suffix = '<div class="clearfix"></div></div><!-- ' . $region_name . ' -->'; 
    }
    return $div_prefix . $region . $div_suffix;
  }
}

/**
 * Breadcrumbs
 */
function om_breadcrumb($breadcrumb) {
  if (!empty($breadcrumb)) {
	  $out = '<div id="breadcrumb">' . $breadcrumb . '</div>'; 
	}
	return $out;
}

/**
 * Process all content elements
 */
function om_content_elements($tabs = NULL, $prefix = NULL, $title = NULL, $suffix = NULL, $messages = NULL, $help = NULL, $action = NULL) {
	$out = '';
  if (!empty($mission)) { $out .= '<div id="mission">' . $mission .'</div>'; }
  if (!empty($tabs)) { $out .= '<div class="tabs">' . $tabs .'</div>'; }
  if (!empty($prefix)) { $out .= $prefix; }
  if (!empty($title)) { $out .= '<h1 class="title" id="page-title">' . $title . '</h1>'; }
  if (!empty($suffix)) { $out .= $suffix; }
  if (!empty($messages)) { $out .= $messages; }
  if (!empty($help)) { $out .= $help; }
  if (!empty($action)) { $out .= $action; }
  return $out;
}


/**
 * Override or insert om variables into the templates.
 *
function om_preprocess_page(&$vars) {
	$vars['tabs2'] = menu_secondary_local_tasks();
	// Generate menu tree from source of primary links
	$vars['primary_links_tree'] = menu_tree(variable_get('menu_primary_links_source', 'primary-links'));
	$vars['secondary_links_tree'] = menu_tree(variable_get('menu_secondary_links_source', 'secondary-links'));
	// Hook into color.module
	if (module_exists('color')) { _color_page_alter($vars); }
	// on devavrata theme
	$vars['closure'] .= '<div id="legal">OM Base Theme ' . date('Y') . ' | V6.x-1.0 | by <a href="http://danielhonrade.com">Daniel Honrade</a></div>';
  // recognize url aliases as file page templates, ex. page-title.tpl.php
  if (module_exists('path')) {
    $alias = drupal_get_path_alias(str_replace('/edit','',$_GET['q']));
    if ($alias != $_GET['q']) {
      $template_filename = 'page';
      foreach (explode('/', $alias) as $path_part) {
        $template_filename = $template_filename . '-' . $path_part;
        $vars['template_files'][] = $template_filename;
      }
    }
  }
	// aggregate css files
  $preprocess_css = variable_get('preprocess_css', 0);
  if (!$preprocess_css) {
    $styles = '';
    foreach ($vars['css'] as $media => $types) {
      $import = '';
      $counter = 0;
      foreach ($types as $files) {
        foreach ($files as $css => $preprocess) {
          $import .= '@import "'. base_path() . $css .'";'."\n";
          $counter++;
          if ($counter == 15) {
            $styles .= "\n".'<style type="text/css" media="'. $media .'">'."\n". $import .'</style>';
            $import = '';
            $counter = 0;
          }
        }
      }
      if ($import) {
        $styles .= "\n".'<style type="text/css" media="'. $media .'">'."\n". $import .'</style>';
      }
    }
    if ($styles) {
      $vars['styles'] = $styles;
    }
  }
	
  $classes = explode(' ', $vars['body_classes']);
  // Remove the mostly useless page-ARG0 class.
  if ($index = array_search(preg_replace('![^abcdefghijklmnopqrstuvwxyz0-9-_]+!s', '', 'page-'. drupal_strtolower(arg(0))), $classes)) {
    unset($classes[$index]);
  }
  if (!$vars['is_front']) {
    // Add unique class for each page.
    $path = drupal_get_path_alias($_GET['q']);
    $classes[] = om_id_safe('page-' . $path);
    // Add unique class for each website section.
    list($section, ) = explode('/', $path, 2);
    if (arg(0) == 'node') {
      if (arg(1) == 'add') {
        $section = 'node-add';
      }
      elseif (is_numeric(arg(1)) && (arg(2) == 'edit' || arg(2) == 'delete')) {
        $section = 'node-' . arg(2);
      }
    }
    $classes[] = om_id_safe('section-' . $section);
  }
  $vars['body_classes_array'] = $classes;
  $vars['body_classes'] = implode(' ', $classes); // Concatenate with spaces.	
}
 
 
/**
 * Generates IE CSS links for LTR and RTL languages.
 */

function om_get_ie_styles($ie) {
  global $language;
  global $theme; 
  switch ($ie) {
    case 'ie' : $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . drupal_get_path('theme', $theme) .'/css/ie.css" />'; break;
    case 'ie6': $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . drupal_get_path('theme', $theme) .'/css/ie6.css" />'; break;
    case 'ie7': $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . drupal_get_path('theme', $theme) .'/css/ie7.css" />'; break;
    case 'ie8': $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . drupal_get_path('theme', $theme) .'/css/ie8.css" />'; break;
    case 'ie9': $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . drupal_get_path('theme', $theme) .'/css/ie9.css" />'; break;
    default   : $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . drupal_get_path('theme', $theme) .'/css/ie8.css" />'; break;
  }
  if ($language->direction == LANGUAGE_RTL) {
    $iecss .= '<style type="text/css" media="all">@import "'. base_path() . drupal_get_path('theme', $theme) .'/css/ie-rtl.css";</style>';
  }
  return $iecss;
}

==> om-7.x-1.1.tar.gz: om/core/template.php <==
<?php
// $Id: template.php,v 1.1.4.2 2011/02/11 07:11:13 danielhonrade Exp $

/**
 * Logo, Site Name, Site Slogan
 */
function om_identity($logo, $site_name, $site_slogan, $front_page) {
  if (!empty($logo)) { 
	  $out = '<div id="logo-title">';
    if (!empty($logo)) { 
      $out .= '<a href="' . $front_page . '" title="' . t('Home') . '" rel="home" id="logo">';
      $out .= '<img src="' . $logo . '" alt="' . t('Home') . '" />';
      $out .= '</a>';
	  }
		if (!empty($logo) || !empty($site_name) || !empty($site_slogan)) { 
        $out .= '<div id="name-and-slogan">';
        if (!empty($site_name)) {
          $out .= '<h1 id="site-name">';
          $out .= '<a href="' . $front_page . '" title=' . t('Home') . '" rel="home">' . $site_name . '</a>';
          $out .= '</h1>';
				}
        if (!empty($site_slogan)) {
          $out .= '<div id="site-slogan">' . $site_slogan . '</div>';
        }
        $out .= '</div> <!-- /name-and-slogan -->';
     }    
     $out .= '</div> <!-- /logo-title -->';
	}
	return $out;
}


/**
 * Primary, Secondary Menus
 *
function om_menu($menu_name = NULL, $menu = NULL, $menu_tree = NULL) {
	if(!empty($menu)) { 
			$output = '<div id="menubar-' . $menu_name. '" class="menubar">' . $menu_tree . '</div>';
  }
  return $output;
}

/**
 * Process all region formats
 */
function om_region_wrapper($region_name = NULL, $region = NULL, $region_inner = 0) {
  if ($region) { 
    if($region_inner == 1) { 
      $div_prefix = '<div id="' . $region_name . '" class="region"><div id="' . $region_name . '-inner" class="region-inner">'; 
      $div_suffix = '<div class="clearfix"></div></div><!-- ' . $region_name . '-inner --></div><!-- ' . $region_name . ' -->'; 
    }
    else {
      $div_prefix = '<div id="' . $region_name . '" class="region">'; 
      $div_suffix = '<div class="clearfix"></div></div><!-- ' . $region_name . ' -->'; 
    }
    return $div_prefix . $region . $div_suffix;
  }
}

/**
 * Breadcrumbs
 */
function om_breadcrumb($breadcrumb) {
  if (!empty($breadcrumb)) {
	  $out = '<div id="breadcrumb">' . $breadcrumb . '</div>'; 
	}
	return $out;
}

/**
 * Process all content elements
 */
function om_content_elements($tabs = NULL, $prefix = NULL, $title = NULL, $suffix = NULL, $messages = NULL, $help = NULL, $action = NULL) {
	$out = '';
  if (!empty($mission)) { $out .= '<div id="mission">' . $mission .'</div>'; }
  if (!empty($tabs)) { $out .= '<div class="tabs">' . $tabs .'</div>'; }
  if (!empty($prefix)) { $out .= $prefix; }
  if (!empty($title)) { $out .= '<h1 class="title" id="page-title">' . $title . '</h1>'; }
  if (!empty($suffix)) { $out .= $suffix; }
  if (!empty($messages)) { $out .= $messages; }
  if (!empty($help)) { $out .= $help; }
  if (!empty($action)) { $out .= $action; }
  return $out;
}


/**
 * Override or insert om variables into the templates.
 *
function om_preprocess_page(&$vars) {
	$vars['tabs2'] = menu_secondary_local_tasks();
	// Generate menu tree from source of primary links
	$vars['primary_links_tree'] = menu_tree(variable_get('menu_primary_links_source', 'primary-links'));
	$vars['secondary_links_tree'] = menu_tree(variable_get('menu_secondary_links_source', 'secondary-links'));
	// Hook into color.module
	if (module_exists('color')) { _color_page_alter($vars); }
	// on devavrata theme
	$vars['closure'] .= '<div id="legal">OM Base Theme ' . date('Y') . ' | V7.x-1.0 | by <a href="http://www.prometsource.com">Promet Source</a></div>';
  // recognize url aliases as file page templates, ex. page-title.tpl.php
  if (module_exists('path')) {
    $alias = drupal_get_path_alias(str_replace('/edit','',$_GET['q']));
    if ($alias != $_GET['q']) {
      $template_filename = 'page';
      foreach (explode('/', $alias) as $path_part) {
        $template_filename = $template_filename . '-' . $path_part;
        $vars['template_files'][] = $template_filename;
      }
    }
  }
	// aggregate css files
  $preprocess_css = variable_get('preprocess_css', 0);
  if (!$preprocess_css) {
    $styles = '';
    foreach ($vars['css'] as $media => $types) {
      $import = '';
      $counter = 0;
      foreach ($types as $files) {
        foreach ($files as $css => $preprocess) {
          $import .= '@import "'. base_path() . $css .'";'."\n";
          $counter++;
          if ($counter == 15) {
            $styles .= "\n".'<style type="text/css" media="'. $media .'">'."\n". $import .'</style>';
            $import = '';
            $counter = 0;
          }
        }
      }
      if ($import) {
        $styles .= "\n".'<style type="text/css" media="'. $media .'">'."\n". $import .'</style>';
      }
    }
    if ($styles) {
      $vars['styles'] = $styles;
    }
  }
	
  $classes = explode(' ', $vars['body_classes']);
  // Remove the mostly useless page-ARG0 class.
  if ($index = array_search(preg_replace('![^abcdefghijklmnopqrstuvwxyz0-9-_]+!s', '', 'page-'. drupal_strtolower(arg(0))), $classes)) {
    unset($classes[$index]);
  }
  if (!$vars['is_front']) {
    // Add unique class for each page.
    $path = drupal_get_path_alias($_GET['q']);
    $classes[] = om_id_safe('page-' . $path);
    // Add unique class for each website section.
    list($section, ) = explode('/', $path, 2);
    if (arg(0) == 'node') {
      if (arg(1) == 'add') {
        $section = 'node-add';
      }
      elseif (is_numeric(arg(1)) && (arg(2) == 'edit' || arg(2) == 'delete')) {
        $section = 'node-' . arg(2);
      }
    }
    $classes[] = om_id_safe('section-' . $section);
  }
  $vars['body_classes_array'] = $classes;
  $vars['body_classes'] = implode(' ', $classes); // Concatenate with spaces.	
}
 
 
/**
 * Generates IE CSS links for LTR and RTL languages.
 */

function om_get_ie_styles($ie) {
  global $language;
  global $theme; 
  switch ($ie) {
    case 'ie' : $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . drupal_get_path('theme', $theme) .'/css/ie.css" />'; break;
    case 'ie6': $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . drupal_get_path('theme', $theme) .'/css/ie6.css" />'; break;
    case 'ie7': $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . drupal_get_path('theme', $theme) .'/css/ie7.css" />'; break;
    case 'ie8': $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . drupal_get_path('theme', $theme) .'/css/ie8.css" />'; break;
    case 'ie9': $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . drupal_get_path('theme', $theme) .'/css/ie9.css" />'; break;
    default   : $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . drupal_get_path('theme', $theme) .'/css/ie8.css" />'; break;
  }
  if ($language->direction == LANGUAGE_RTL) {
    $iecss .= '<style type="text/css" media="all">@import "'. base_path() . drupal_get_path('theme', $theme) .'/css/ie-rtl.css";</style>';
  }
  return $iecss;
}
